@@ -1,6 +1,6 @@
 #  gcompris - login
 #
-# Copyright (C) 2005 Bruno Coudoin
+# Copyright (C) 2005, 2008 Bruno Coudoin
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -15,7 +15,7 @@
 #   You should have received a copy of the GNU General Public License
 #   along with this program; if not, see <http://www.gnu.org/licenses/>.
 #
-import gnomecanvas
+import goocanvas
 import gcompris
 import gcompris.utils
 import gcompris.skin
@@ -29,11 +29,11 @@ import math
 
 # Background screens
 backgrounds = [
-  "opt/scenery2_background.png",
-  "opt/scenery3_background.png",
-  "opt/scenery4_background.png",
-  "opt/scenery5_background.png",
-  "opt/scenery6_background.png"
+  "login/scenery2_background.png",
+  "login/scenery3_background.png",
+  "login/scenery4_background.png",
+  "login/scenery5_background.png",
+  "login/scenery6_background.png"
 ]
 
 MAX_USERS_AT_ONCE = 10
@@ -44,11 +44,9 @@ class Gcompris_login:
 
   def __init__(self, gcomprisBoard):
     self.gcomprisBoard = gcomprisBoard
-    self.entry = []
 
     self.gcomprisBoard.disable_im_context = True
-
-    print("Gcompris_login __init__.")
+    self.entry = []
 
 
   def start(self):
@@ -56,26 +54,22 @@ class Gcompris_login:
     self.gcomprisBoard.maxlevel=1
     self.gcomprisBoard.sublevel=1
     self.gcomprisBoard.number_of_sublevel=1
-    pixmap = gcompris.utils.load_pixmap(gcompris.skin.image_to_skin("button_reload.png"))
-    if(pixmap):
-      gcompris.bar_set_repeat_icon(pixmap)
-      gcompris.bar_set(gcompris.BAR_REPEAT_ICON)
-    else:
-      gcompris.bar_set(gcompris.BAR_REPEAT)
+    gcompris.bar_set(gcompris.BAR_REPEAT)
 
     gcompris.bar_set_level(self.gcomprisBoard)
 
-    gcompris.set_background(self.gcomprisBoard.canvas.root(),
+    gcompris.set_background(self.gcomprisBoard.canvas.get_root_item(),
                             backgrounds[self.gcomprisBoard.level-1])
 
     # Get the default profile
     self.Prop = gcompris.get_properties()
 
+    if not self.Prop:
+      return
+
     # init config to default values
     self.config_dict = self.init_config()
 
-    print gcompris.get_board_conf(), self.gcomprisBoard.board_id, self.gcomprisBoard.name
-
     # change configured values
     self.config_dict.update(gcompris.get_board_conf())
 
@@ -94,45 +88,27 @@ class Gcompris_login:
     else:
       self.display_user_by_letter(self.users, "")
 
-    print("Gcompris_login start.")
-
 
   def init_rootitem(self, Prop):
-    print "__rootitem__"
     # Create our rootitem.
     # We put each canvas item in it so at the end we only have to kill it.
     # The canvas deletes all the items it contains automaticaly.
-    self.rootitem = self.gcomprisBoard.canvas.root().add(
-      gnomecanvas.CanvasGroup,
-      x=0.0,
-      y=0.0
-      )
+    self.rootitem = goocanvas.Group(parent =  self.gcomprisBoard.canvas.get_root_item())
 
     # Display the profile name
     x = gcompris.BOARD_WIDTH-100
     y = 20.0
     text = _("Profile: ") + Prop.profile.name
 
-    # Shadow
-    self.rootitem.add(
-      gnomecanvas.CanvasText,
-      x= x + 1,
-      y= y + 1,
-      text= text,
-      fill_color="black",
-      font=gcompris.skin.get_font("gcompris/board/small"),
-      justification=gtk.JUSTIFY_RIGHT
-      )
-
     # Profile name
-    self.rootitem.add(
-      gnomecanvas.CanvasText,
+    goocanvas.Text(
+      parent = self.rootitem,
       x= x,
       y= y,
       text= text,
       fill_color="white",
       font=gcompris.skin.get_font("gcompris/board/small"),
-      justification=gtk.JUSTIFY_RIGHT
+      anchor = gtk.ANCHOR_CENTER
       )
 
 
@@ -152,16 +128,15 @@ class Gcompris_login:
   def end(self):
 
     # Remove the root item removes all the others inside it
-    self.rootitem.destroy()
+    self.rootitem.remove()
 
 
   def ok(self):
-    print("Gcompris_login ok.")
+    pass
 
 
   def repeat(self):
-    print("Gcompris_login repeat.")
-    self.rootitem.destroy()
+    self.rootitem.remove()
 
     self.init_rootitem(self.Prop)
 
@@ -171,29 +146,26 @@ class Gcompris_login:
       self.display_user_by_letter(self.users, "")
 
   def config(self):
-    print("Gcompris_login config.")
+    pass
 
 
   def key_press(self, keyval, commit_str, preedit_str):
-    print("Gcompris_login key press. %i" % keyval)
-
     # Return  True  if you did process a key
     # Return  False if you did not processed a key
     #         (gtk need to send it to next widget)
     return False
 
   def pause(self, pause):
-    print("Gcompris_login pause. %i" % pause)
     # There is a problem with GTK widgets, they are not covered by the help
     # We hide/show them here
     if(pause):
-      if self.entry: self.entry.hide()
+      if self.entry: self.widget.props.visibility = goocanvas.ITEM_INVISIBLE
     else:
-      if self.entry: self.entry.show()
+      if self.entry: self.widget.props.visibility = goocanvas.ITEM_VISIBLE
 
 
   def set_level(self, level):
-    print("Gcompris_login set level. %i" % level)
+    pass
 
   # -------------------------------
   # ---- End of Initialisation ----
@@ -211,8 +183,6 @@ class Gcompris_login:
   #
   def display_user_by_letter(self, users, start_filter):
 
-    print "display_user_by_letter start_filter=" + start_filter
-
     first_letters = []
     current_letter = None
     remaining_users=0
@@ -247,11 +217,7 @@ class Gcompris_login:
   def display_letters(self, letters, users, start_filter):
 
     # Create a group for the letters
-    self.letter_rootitem = self.rootitem.add(
-      self.rootitem,
-      x=0.0,
-      y=0.0
-      )
+    self.letter_rootitem = goocanvas.Group(parent = self.rootitem)
 
     #
     # Display the current filter
@@ -260,18 +226,9 @@ class Gcompris_login:
     x = gcompris.BOARD_WIDTH/2
     y = 20
 
-    # The shadow
-    self.letter_rootitem.add(
-      gnomecanvas.CanvasText,
-      x= x + 1.5,
-      y= y + 1.5,
-      text= _("Login: ") + start_filter + "...",
-      fill_color="black",
-      font=gcompris.skin.get_font("gcompris/board/huge"),
-      )
     # The text
-    self.letter_rootitem.add(
-      gnomecanvas.CanvasText,
+    goocanvas.Text(
+      parent = self.letter_rootitem,
       x= x,
       y= y,
       text= _("Login: ") + start_filter + "...",
@@ -292,7 +249,6 @@ class Gcompris_login:
     current_line = 0
     max_letter_by_line = (gcompris.BOARD_WIDTH-start_x*2)/step_x
     letter_by_line = max_letter_by_line
-    button_pixbuf = gcompris.utils.load_pixmap(gcompris.skin.image_to_skin("ok.png"))
 
     for letter in letters:
 
@@ -302,40 +258,40 @@ class Gcompris_login:
       else:
         text = letter.upper() + letter.lower()
 
-      item = self.letter_rootitem.add(
-        gnomecanvas.CanvasPixbuf,
-        pixbuf = button_pixbuf,
-        x = x -  button_pixbuf.get_width()/2,
-        y = y -  button_pixbuf.get_height()/2,
-        )
-      # This item is clickeable and it must be seen
-      item.connect("event", gcompris.utils.item_event_focus)
-      item.connect("event", self.letter_click_event,
-                   (users, start_filter + letter))
-
-      # The shadow
-      item = self.letter_rootitem.add(
-        gnomecanvas.CanvasText,
-        x= x + 1.5,
-        y= y + 1.5,
-        text= text,
-        fill_color="black",
-        font=gcompris.skin.get_font("gcompris/board/huge"),
-        )
-      item.connect("event", self.letter_click_event,
-                   (users, start_filter + letter))
-
       # The text
-      item = self.letter_rootitem.add(
-        gnomecanvas.CanvasText,
+      item =goocanvas.Text(
+        parent = self.letter_rootitem,
         x= x,
         y= y,
         text= text,
         fill_color="white",
         font=gcompris.skin.get_font("gcompris/board/huge"),
         )
-      item.connect("event", self.letter_click_event,
+      item.connect("button_press_event", self.letter_click_event,
                    (users, start_filter + letter))
+
+      gap = 10
+      bounds = item.get_bounds()
+      item_bg = \
+          goocanvas.Rect(
+          parent = self.letter_rootitem,
+          x = bounds.x1 - gap,
+          y = bounds.y1 - gap,
+          width = bounds.x2 - bounds.x1 + gap*2,
+          height = bounds.y2 - bounds.y1 + gap*2,
+          line_width=2.0,
+          fill_color_rgba=0x555555CAL,
+          stroke_color_rgba=0xFFFFFFFFL,
+          radius_x=5.0,
+          radius_y=5.0)
+      # This item is clickeable and it must be seen
+      gcompris.utils.item_focus_init(item, item_bg)
+      gcompris.utils.item_focus_init(item_bg, None)
+      item_bg.connect("button_press_event", self.letter_click_event,
+                      (users, start_filter + letter))
+      item.raise_(None)
+
+
       x += step_x
 
       i += 1
@@ -365,7 +321,6 @@ class Gcompris_login:
     x = gcompris.BOARD_WIDTH/4
     i = 0
     step_y = 90
-    button_pixbuf = gcompris.utils.load_pixmap(gcompris.skin.image_to_skin("button_large2.png"))
 
     for user in users:
       if eval(self.config_dict['uppercase_only']):
@@ -376,38 +331,37 @@ class Gcompris_login:
       if not login.startswith(start_filter):
         continue
 
-      item = self.rootitem.add(
-        gnomecanvas.CanvasPixbuf,
-        pixbuf = button_pixbuf,
-        x = x -  button_pixbuf.get_width()/2,
-        y = y -  button_pixbuf.get_height()/2,
-        )
-      # This item is clickeable and it must be seen
-      item.connect("event", gcompris.utils.item_event_focus)
-      item.connect("event", self.name_click_event, user)
-
-
-      # The shadow
-      item = self.rootitem.add(
-        gnomecanvas.CanvasText,
-        x= x + 1.5,
-        y= y + 1.5,
-        text= login,
-        fill_color="black",
-        font=gcompris.skin.get_font("gcompris/board/huge"),
-        )
-      item.connect("event", self.name_click_event, user)
-
       # The text
-      item = self.rootitem.add(
-        gnomecanvas.CanvasText,
+      item = goocanvas.Text(
+        parent = self.rootitem,
         x= x,
         y= y,
         text= login,
         fill_color="white",
         font=gcompris.skin.get_font("gcompris/board/huge"),
+        anchor = gtk.ANCHOR_CENTER,
         )
-      item.connect("event", self.name_click_event, user)
+      item.connect("button_press_event", self.name_click_event, user)
+
+      gap = 10
+      bounds = item.get_bounds()
+      item_bg = \
+          goocanvas.Rect(
+          parent = self.rootitem,
+          x = bounds.x1 - gap,
+          y = bounds.y1 - gap,
+          width = bounds.x2 - bounds.x1 + gap*2,
+          height = bounds.y2 - bounds.y1 + gap*2,
+          line_width=2.0,
+          fill_color_rgba=0x555555CAL,
+          stroke_color_rgba=0xFFFFFFFFL,
+          radius_x=5.0,
+          radius_y=5.0)
+      item_bg.connect("button_press_event", self.name_click_event, user)
+      item.raise_(item_bg)
+      # This item is clickeable and it must be seen
+      gcompris.utils.item_focus_init(item, item_bg)
+      gcompris.utils.item_focus_init(item_bg, None)
 
       y += step_y
       i += 1
@@ -422,9 +376,9 @@ class Gcompris_login:
   # Event when a click happen on a letter
   # data[0] is the user list we work on
   # data[1] is the start filter
-  def letter_click_event(self, widget, event, data):
+  def letter_click_event(self, widget, target, event, data):
     if event.type == gtk.gdk.BUTTON_PRESS:
-      self.letter_rootitem.destroy()
+      self.letter_rootitem.remove()
       self.display_user_by_letter(data[0], data[1])
       return True
 
@@ -433,10 +387,8 @@ class Gcompris_login:
   #
   # Event when a click happen on a user name
   #
-  def name_click_event(self, widget, event, user):
+  def name_click_event(self, widget, target, event, user):
     if event.type == gtk.gdk.BUTTON_PRESS:
-      print "selected user = " + user.login
-
       self.logon(user)
       return True
 
@@ -455,13 +407,12 @@ class Gcompris_login:
 
 
   def entry_text(self):
-    print "__entry__"
     self.entry = gtk.Entry()
 
     self.entry.modify_font(pango.FontDescription("sans bold 36"))
-    text_color = gtk.gdk.color_parse("brown")
-    text_color_selected = gtk.gdk.color_parse("brown")
-    bg_color = gtk.gdk.color_parse("blue")
+    text_color = gtk.gdk.color_parse("black")
+    text_color_selected = gtk.gdk.color_parse("black")
+    bg_color = gtk.gdk.color_parse("white")
 
     self.entry.modify_text(gtk.STATE_NORMAL, text_color)
     self.entry.modify_text(gtk.STATE_SELECTED, text_color_selected)
@@ -471,24 +422,18 @@ class Gcompris_login:
     self.entry.connect("activate", self.enter_callback)
     self.entry.connect("changed", self.enter_char_callback)
 
-    self.entry.show()
-
-    self.widget = self.rootitem.add(
-      gnomecanvas.CanvasWidget,
+    self.widget = goocanvas.Widget(
+      parent = self.rootitem,
       widget=self.entry,
       x=400,
       y=400,
       width=400,
       height=72,
       anchor=gtk.ANCHOR_CENTER,
-      size_pixels=False
       )
 
-    self.widget.raise_to_top()
+    self.widget.raise_(None)
 
-    # does not work. Why ?
-    #self.gcomprisBoard.canvas.grab_focus()
-    self.widget.grab_focus()
     self.entry.grab_focus()
 
   def enter_char_callback(self, widget):
@@ -506,7 +451,7 @@ class Gcompris_login:
       else:
         login = user.login
       if text == login:
-        self.widget.destroy()
+        self.widget.remove()
         self.logon(user)
         found = True
 
@@ -514,7 +459,6 @@ class Gcompris_login:
       widget.set_text('')
 
   def config_start(self, profile):
-    print '__login config__'
     # keep profile in mind
     self.configuring_profile = profile
 
